# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cryton_cli',
 'cryton_cli.etc',
 'cryton_cli.lib',
 'cryton_cli.lib.commands',
 'cryton_cli.lib.util']

package_data = \
{'': ['*']}

install_requires = \
['Jinja2>=3.0.3,<3.1.0',
 'PyYAML>=6.0,<6.1',
 'click>=8.1.2,<8.2.0',
 'pyfiglet>=0.8.post1,<0.9',
 'python-dotenv>=0.20.0,<0.21.0',
 'pytz>=2021.3,<2021.4',
 'requests>=2.27.0,<2.28.0',
 'termcolor>=1.1.0,<1.2.0',
 'tzlocal>=4.1,<4.2']

entry_points = \
{'console_scripts': ['cryton-cli = cryton_cli.lib.cli:cli']}

setup_kwargs = {
    'name': 'cryton-cli',
    'version': '2022.2.1',
    'description': 'Command line interface for Cryton Core',
    'long_description': '[[_TOC_]]\n\n![Coverage](https://gitlab.ics.muni.cz/cryton/cryton-cli/badges/master/coverage.svg)\n\n# Cryton CLI\n\n## Description\nCryton CLI is a command line interface used to interact with [Cryton Core](https://gitlab.ics.muni.cz/cryton/cryton-core) (its API).\n\nTo be able to execute attack scenarios, you also need to install **[Cryton Core](https://gitlab.ics.muni.cz/cryton/cryton-core)** \nand **[Cryton Worker](https://gitlab.ics.muni.cz/cryton/cryton-worker)** tools.\n\nCryton toolset is tested and targeted primarily on **Debian** and **Kali Linux**. Please keep in mind that \n**only the latest version is supported** and issues regarding different OS or distributions may **not** be resolved.\n\n[Link to the documentation](https://cryton.gitlab-pages.ics.muni.cz/cryton-documentation/).\n\n## Settings\nCryton CLI uses environment variables for its settings. Please update them to your needs.\n\n| name                      | value   | example              | description                                                                                                                                                                                     |\n|---------------------------|---------|----------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|\n| CRYTON_CLI_TIME_ZONE      | string  | AUTO                 | What [timezone](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) to use for scheduling (for example when scheduling a Run). <br> Use the `AUTO` value to use your system timezone. |\n| CRYTON_CLI_API_HOST       | string  | 127.0.0.1            | Cryton Core\'s API address.                                                                                                                                                                      |\n| CRYTON_CLI_API_PORT       | int     | 8000                 | Cryton Core\'s API port.                                                                                                                                                                         |\n| CRYTON_CLI_API_SSL        | boolean | false                | Use SSL to connect to REST API.                                                                                                                                                                 |\n| CRYTON_CLI_API_ROOT       | string  | api/                 | REST API URL. **(do not change, if you don\'t know what you\'re doing)**                                                                                                                          |\n| CRYTON_CLI_APP_DIRECTORY  | string  | ~/.local/cryton-cli/ | Path to the Cryton CLI directory. **(do not change/set/export, if you don\'t know what you\'re doing)** <br> If changed, update the commands in this guide accordingly.                           |\n\nTo save the settings **create an app directory**:\n```shell\nmkdir ~/.local/cryton-cli/\n```\n\nNext, we download example settings (**change the version to match the app version**):\n```shell\ncurl -o ~/.local/cryton-cli/.env https://gitlab.ics.muni.cz/cryton/cryton-cli/-/raw/<version>/.env\n```\n\nUpdate these settings to your needs.\n\n### Overriding the settings\nTo override the persistent settings, you can set/export the variables yourself using the **export** command \n(use **unset** to remove the variable). For example:\n```shell\nexport CRYTON_CLI_API_HOST=127.0.0.1\n```\n\nSome environment variables can be overridden in CLI. Try using `cryton-cli --help`.\n\n## Installation\nCryton CLI is available in the [PyPI](https://pypi.org/project/cryton-cli/) and can be installed using *pip* (`pip install --user cryton-cli`). \nHowever, we **highly recommend** installing the app in an isolated environment using [pipx](https://pypa.github.io/pipx/).\n\n### Requirements\nInstall the following requirements:\n- [Python](https://www.python.org/about/gettingstarted/) >=3.8\n- [pipx](https://pypa.github.io/pipx/)\n\n### Installing with pipx\nOnce you have *pipx* ready on your system, you can start the installation:\n```shell\npipx install cryton-cli\n```\n\nMake sure you\'ve correctly set the [settings](#settings).\n\nOptionally, you can set up [shell completion](#shell-completion).\n\nEverything should be set, check out the [usage section](#usage).\n\n## Development\nTo install Cryton CLI for development, you must install [Poetry](https://python-poetry.org/docs/).\n\nClone the repository:\n```shell\ngit clone https://gitlab.ics.muni.cz/cryton/cryton-cli.git\n```\n\nThen go to the correct directory and install the project:\n```shell\ncd cryton-cli\npoetry install\n```\n\nTo spawn a shell use:\n```shell\npoetry shell\n```\n\nMake sure you\'ve correctly set the [settings](#settings).  \nTo override the settings quickly, you can use this handy one-liner:\n```shell\nexport $(grep -v \'^#\' .env | xargs)\n```\n\nOptionally, you can set up [shell completion](#shell-completion).\n\nEverything should be set. Check out the [usage section](#usage).\n\n## Usage\nUse the following to invoke the app:\n```shell\ncryton-cli\n```\n\nYou should see a help page:\n```\nUsage: cryton-cli [OPTIONS] COMMAND [ARGS]...\n\n  A CLI wrapper for Cryton API.\n\nOptions:\n  ...\n```\n\n**Please keep in mind that the [Cryton Core](https://gitlab.ics.muni.cz/cryton/cryton-core) \nmust be running and its API must be reachable.**\n\nTo change the default API host/port use *-H* and *-p* options (to change them permanently, see the [settings section](#settings)).\n```shell\ncryton-cli -H 127.0.0.1 -p 8000 <your command>\n```\n\n**To learn about each command\'s options use**:\n```shell\ncryton-cli <your command> --help\n```\n\nFor a better understanding of the results, we highlight the successful ones with **green** and the others with **red** color.\n\n### Example\n#### 1. Create plan template\nCreate a plan template using a file containing the desired plan YAML.\n```shell\ncryton-cli plan-templates create my-plan.yml\n```\n\nDesired output:\n```\nTemplate successfully created! (<response detail>).\n```\n\n#### 2. Create Plan instance\nCreate a Plan instance with the saved plan template.\n```shell\ncryton-cli plans create 1\n```\n\nCreate a Plan instance using the template and an inventory file.\n```shell\ncryton-cli plans create 1 -i inventory_file\n```\n\nDesired output:\n```\nPlan successfully created! (<response detail>).\n```\n\n#### 3. Create Worker\nTo execute Plans (Runs) we have to define a Worker(s).\n```shell\ncryton-cli workers create customName -d "This is my first Worker!"\n```\n\nDesired output:\n```\nWorker successfully created! (<response detail>).\n```\n\n#### 4. Create Run\nCreate a Run by choosing a Plan instance and providing a list of Workers for execution.\n```shell\ncryton-cli runs create 1 1\n```\n\nDesired output:\n```\nRun successfully created! (<response detail>).\n```\n\n#### 5. Schedule or execute Run\nYou can either schedule the Run for a specific date/time or execute it directly. Run will then be executed on every Worker \nsimultaneously.\n\n**Execute Run**  \n```shell\ncryton-cli runs execute 1\n```\n\nDesired output:\n```\nRun successfully executed! (Run 1 was executed.).\n```\n\n**Schedule Run**  \nYou can schedule a Run using the local timezone.\n```shell\ncryton-cli runs schedule 1 2020-06-08 10:00:00\n```\n\nDesired output:\n```\nRun successfully scheduled! (Run 1 is scheduled for 2020-06-08 10:00:00.).\n```\n\nOr you can schedule it using UTC timezone with the flag `--utc-timezone`. Otherwise, your preset timezone is used.\n\n#### 6. Read Run report\nA report can be generated anytime during the execution (also compliant with YAML format). It contains a list of \nStages/Steps and their results. \n```shell\ncryton-cli runs report 1\n```\n\nDesired output:\n```\nSuccessfully created Run\'s report! (file saved at: /tmp/report_run_1_2020-06-08-10-15-00-257994_xdQeV)\n```\n\nTimestamps are displayed in UTC timezone by default. Use the `--localize` flag to display them using your preset timezone.\n\n## Shell completion\nShell completion is available for the *Bash*, *Zsh*, and *Fish* shell and has to be manually enabled (**the tool must be installed first**).\n\n### Bash\nFirst, **create an app directory** (if you haven\'t already):\n```shell\nmkdir ~/.local/cryton-cli/\n```\n\nGenerate and save the completion script:\n```shell\n_CRYTON_CLI_COMPLETE=bash_source cryton-cli > ~/.local/cryton-cli/cryton-cli-complete.bash\n```\n\nSource the file in the `~/.bashrc` file:\n```shell\necho ". ~/.local/cryton-cli/cryton-cli-complete.bash" >> ~/.bashrc\n```\n\nYou may need to restart your shell for the changes to take effect.\n\n### Zsh\nFirst, **create an app directory** (if you haven\'t already):\n```shell\nmkdir ~/.local/cryton-cli/\n```\n\nGenerate and save the completion script:\n```shell\n_CRYTON_CLI_COMPLETE=zsh_source cryton-cli > ~/.local/cryton-cli/cryton-cli-complete.zsh\n```\n\nSource the file in the `~/.zshrc` file:\n```shell\necho ". ~/.local/cryton-cli/cryton-cli-complete.zsh" >> ~/.zshrc\n```\n\nYou may need to restart your shell for the changes to take effect.\n\n### Fish\nGenerate and save the completion script:\n```shell\n_CRYTON_CLI_COMPLETE=fish_source cryton-cli > ~/.config/fish/completions/cryton-cli-complete.fish\n```\n\nYou may need to restart your shell for the changes to take effect.\n',
    'author': 'Ivo Nutár',
    'author_email': 'nutar@ics.muni.cz',
    'maintainer': 'Jiří Rája',
    'maintainer_email': 'raja@ics.muni.cz',
    'url': 'https://gitlab.ics.muni.cz/cryton',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
